@@ -110,96 +110,6 @@ QString midiMetaName(int meta)
       return QString(s);
       }
 
-//---------------------------------------------------------
-//   dump
-//---------------------------------------------------------
-
-void NoteEvent::dump(Xml& xml) const
-      {
-      xml.tagE(QString("Note  tick=\"%1\" channel=\"%2\" len=\"%3\" pitch=\"%4\" velo=\"%5\"")
-         .arg(ontime()).arg(channel()).arg(duration()).arg(pitch()).arg(velo()));
-      }
-
-void NoteOn::dump(Xml& xml) const
-      {
-      xml.tagE(QString("NoteOn  tick=\"%1\" channel=\"%2\" pitch=\"%3\" velo=\"%4\"")
-            .arg(ontime()).arg(channel()).arg(pitch()).arg(velo()));
-      }
-
-void NoteOff::dump(Xml& xml) const
-      {
-      xml.tagE(QString("NoteOff  tick=\"%1\" channel=\"%2\" pitch=\"%3\" velo=\"%4\"")
-            .arg(ontime()).arg(channel()).arg(pitch()).arg(velo()));
-      }
-
-void ControllerEvent::dump(Xml& xml) const
-      {
-      xml.tagE(QString("Controller tick=\"%1\" channel=\"%2\" ctrl=\"%3\" value=\"%4\"")
-         .arg(ontime()).arg(channel()).arg(controller()).arg(value()));
-      }
-
-void SysexEvent::dump(Xml& xml) const
-      {
-      xml.stag(QString("Sysex tick=\"%1\" len=\"%2\"").arg(ontime()).arg(_len));
-      xml.dump(_len, _data);
-      xml.etag();
-      }
-
-void MetaEvent::dump(Xml& xml) const
-      {
-      switch(metaType()) {
-            case META_TRACK_NAME:
-                  xml.tag(QString("TrackName tick=\"%1\"").arg(ontime()), QString((char*)(data())));
-                  break;
-
-            case META_LYRIC:
-                  xml.tag(QString("Lyric tick=\"%1\"").arg(ontime()), QString((char*)(data())));
-                  break;
-
-            case META_KEY_SIGNATURE:
-                  {
-                  const char* keyTable[] = {
-                        "Ces", "Ges", "Des", "As", "Es", "Bes", "F",
-                        "C",
-                        "G", "D", "A", "E", "B", "Fis", "Cis"
-                        };
-                  int key = (char)(_data[0]) + 7;
-                  if (key < 0 || key > 14) {
-                        printf("bad key signature %d\n", key);
-                        key = 0;
-                        }
-                  QString sex(_data[1] ? "Minor" : "Major");
-                  QString keyName(keyTable[key]);
-                  xml.tag(QString("Key tick=\"%1\" key=\"%2\" sex=\"%3\"").arg(ontime()).arg(_data[0]).arg(_data[1]),
-                     QString("%1 %2").arg(keyName).arg(sex));
-                  }
-                  break;
-
-            case META_TIME_SIGNATURE:
-                  xml.tagE(QString("TimeSig tick=\"%1\" num=\"%2\" denom=\"%3\" metro=\"%4\" quarter=\"%5\"")
-                     .arg(ontime())
-                     .arg(int(_data[0]))
-                     .arg(int(_data[1]))
-                     .arg(int(_data[2]))
-                     .arg(int(_data[3])));
-                  break;
-
-            case META_TEMPO:
-                  {
-                  unsigned tempo = _data[2] + (_data[1] << 8) + (_data[0] << 16);
-                  xml.tagE(QString("Tempo tick=\"%1\" value=\"%2\"").arg(ontime()).arg(tempo));
-                  }
-                  break;
-
-            default:
-                  xml.stag(QString("Meta tick=\"%1\" type=\"%2\" len=\"%3\" name=\"%4\"")
-                     .arg(ontime()).arg(metaType()).arg(_len).arg(midiMetaName(metaType())));
-                  xml.dump(_len, _data);
-                  xml.etag();
-                  break;
-            }
-      }
-
 //---------------------------------------------------------
 //   MidiFile
 //---------------------------------------------------------
@@ -274,69 +184,6 @@ bool MidiFile::writeTrack(const MidiTrack* t)
       return false;
       }
 
-//---------------------------------------------------------
-//   write
-//---------------------------------------------------------
-
-void NoteOn::write(MidiFile* mf) const
-      {
-      mf->writeStatus(ME_NOTEON, channel());
-      mf->put(pitch());
-      mf->put(velo());
-      }
-
-void NoteOff::write(MidiFile* mf) const
-      {
-      mf->writeStatus(ME_NOTEOFF, channel());
-      mf->put(pitch());
-      mf->put(velo());
-      }
-
-void ControllerEvent::write(MidiFile* mf) const
-      {
-      switch(controller()) {
-            case CTRL_PROGRAM:
-                  mf->writeStatus(ME_PROGRAM, channel());
-                  mf->put(value());
-                  break;
-            case CTRL_PITCH:
-                  {
-                  mf->writeStatus(ME_PITCHBEND, channel());
-                  int v = value() + 8192;
-                  mf->put(v & 0x7f);
-                  mf->put((v >> 7) & 0x7f);
-                  }
-                  break;
-            case CTRL_PRESS:
-                  mf->writeStatus(ME_AFTERTOUCH, channel());
-                  mf->put(value());
-                  break;
-            default:
-                  mf->writeStatus(ME_CONTROLLER, channel());
-                  mf->put(controller());
-                  mf->put(value());
-                  break;
-            }
-      }
-
-void MetaEvent::write(MidiFile* mf) const
-      {
-      mf->put(ME_META);
-      mf->put(_metaType);
-      mf->putvl(len());
-      mf->write(data(), len());
-      mf->resetRunningStatus();     // really ?!
-      }
-
-void SysexEvent::write(MidiFile* mf) const
-      {
-      mf->put(ME_SYSEX);
-      mf->putvl(len() + 1);  // including 0xf7
-      mf->write(data(), len());
-      mf->put(ME_ENDSYSEX);
-      mf->resetRunningStatus();
-      }
-
 //---------------------------------------------------------
 //   writeStatus
 //---------------------------------------------------------
@@ -364,6 +211,8 @@ bool MidiFile::read(QIODevice* in)
       _error = "";
       _tracks.clear();
       _siglist.clear();
+      _siglist.add(0, 4, 4);   // default time signature
+
       curPos    = 0;
 
       char tmp[4];
